function [ZZ] = ability_threshold(x,n,k,Q,tau,Fn)

    %%% Finds the varphi_thresholds across number of export markets

    global gamma beta phi
    
    % Auxiliary variables
    ups_n_1 = 1+(n-1)*tau^(-beta/(1-beta));
    ups_n   = 1+n*tau^(-beta/(1-beta));
    Fn_cum  = cumsum([0;Fn]);
    
    % Endogenous variables
    varphi_n = x(1);
    l_n_1    = x(2);
    l_n      = x(3);
    
    %%% FOC equations for l_n
    FOC_n_1 = k*( (ups_n_1.^(1-beta)) .* (Q^(1-beta)) .* varphi_n.^beta ).^(1-phi);
    FOC_n_1 = beta*(1-phi)*FOC_n_1;
    FOC_n   = k*( (ups_n.^(1-beta)) .* (Q^(1-beta)) .* varphi_n.^beta ).^(1-phi);
    FOC_n   = beta*(1-phi)*FOC_n;
    
    ZZ_l = [FOC_n_1 - l_n_1.^(gamma-beta*(1-phi));
            FOC_n   - l_n.^(gamma-beta*(1-phi))];
    
    %%% Utility equations 
    U_n_1 = ( k * ( ups_n_1.^(1-beta) * Q^(1-beta) .* (varphi_n.*l_n_1).^beta   ).^(1-phi) - Fn_cum(n)   )  - (1/gamma)*l_n_1.^gamma;
    U_n   = ( k * ( ups_n.^(1-beta) * Q^(1-beta)   .* (varphi_n.*l_n  ).^beta   ).^(1-phi) - Fn_cum(n+1) )  - (1/gamma)*l_n.^gamma;
    
    % Solve for
    ZZ = [ZZ_l;
          U_n-U_n_1];
      
    ZZ = real(ZZ);
            
    end
    
    