function [varphi,sol_all] = ability_varphi(r,k,Q,N,x0,tau,Fn)

    %%% Finds the calibrated varphi draws conditional on an income
    %%% distribution and a set of parameters.
    
    global gamma beta phi
    
    %%% 1. Find varphi thresholds
    fminopt          = optimset('MaxFunEvals',10000,'MaxIter',10000,'Display','off','TolX',10e-15,'TolFun',10e-15);
    sol_all = [];
    for n=1:1:max(N)
        [xsol,fsol,esol] = fsolve(@(x)ability_threshold(x,n,k,Q,tau,Fn),x0,fminopt);
        x0 = xsol;
        sol_all       = [sol_all;xsol,fsol,esol*ones(3,1)];
        varphi_n(n,1) = real(xsol(1)); 
    end    
    NN       = max(N);
    
    % Limits for varphi
    fprintf('\n'),display('-> varphi thresholds for exporting')
    varphi_lim = [(0:1:NN)',[0;varphi_n],[varphi_n;Inf]]

    %%% 2. Solve for each varphi_i
    varphi_all = [];
    for m=1:1:length(r)

        % Flag those that do not fit in either bin, this is only an issue at
        % the thresholds since in the model's income distribution there are
        % jumps while in the data there are not.
        flag = 0;
        [~,varphi_r] = ability_matchr(r(m),N,k,Q,tau,Fn);

        % Comparison with the limits
        lim_diff = [varphi_lim(:,3)-varphi_r,varphi_r-varphi_lim(:,2)];
        [n_r,~]  = ind2sub(size(lim_diff(:,1)),find( (lim_diff(:,1)>0).*(lim_diff(:,2)>0)==1 ));

        if isempty(n_r)==1
            n_r  = varphi_all(end,2)+1;
            flag = 1;
        end

        varphi_all = [varphi_all;varphi_r(n_r),n_r-1,m,flag];
    end
    
    varphi = varphi_all(:,1);
    
end