function [n_export,l,y,r,Q_new,k_new,u0,Phi,u_total] = k_and_Q_equilibrium(varphi,Q0,k0,tau,fn)
    
    % Find solution of model using fixed point algorithm, taking as
    % primitives the parameters and the ability draws.
    
    global gamma beta phi
    
    eps     = beta/(gamma-beta);
    n_draws = length(varphi);
    
    k = k0;
    Q = Q0;
    N = length(fn);
    
    ups      = @(n)(1+n*tau^(-beta/(1-beta)));
    n_lin    = linspace(1,N,N);
    ups_diff = @(n)(ups(n+1).^((1+eps)*(1-beta)*(1-phi)/(1+eps*phi))-ups(n).^((1+eps)*(1-beta)*(1-phi)/(1+eps*phi)));
    ups_diff_vec = ups_diff(repmat(n_lin-1,n_draws,1));
    
    tol = 1;
    count = 0;
    
    while tol>10e-10 && count<1000
    
        r0 = ((beta*(1-phi)*k)^(eps/(1+eps*phi)))*((Q^(1-beta))*(varphi.^beta)).^((1+eps)/(1+eps*phi));
        u0 = ((1+eps*phi)/(1+eps))*k*(r0.^(1-phi));
    
        export     = ups_diff_vec.*repmat(u0,1,N)-repmat(fn',n_draws,1);
        export_dum = max(export,0);
        n_export   = sum(sign(export_dum),2);
    
        % Solution
        l   = ((beta*k*(1-phi)).^((eps/beta)/(1+eps*phi)))*(((ups(n_export).*Q).^(1-beta)).*varphi.^beta).^((eps/beta)*(1-phi)/(1+eps*phi));
        y   = varphi.*l;
        r   = ((ups(n_export).*Q).^(1-beta)).*y.^beta;
               
        Q_new   = (mean(((ups(n_export).^(1-beta)).*(y.^beta)))).^(1/beta);
        k_new   = sum(r)./sum(r.^(1-phi));
        
        tol = norm([Q;k]-[Q_new;k_new],2);

        Q = Q_new;
        k = k_new;
        
        count=count+1;
        
    end
    
    u_total = (ups(n_export).^((1+eps)*(1-beta)*(1-phi)/(1+eps*phi))).*u0-sign(export_dum)*fn;   
    Phi     = u_total./u0; 
    
end
   