
clear all 
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% REPLICATES Figure 6: Counterfactuals holding phi and delta constant
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% I. Setup

%%% I.I Data
addpath('CODE_EQUILIBRIUM')
load('DATA/AGI_LN_approx.mat')
load('DATA/PHI.mat')
load('DATA/BLS_CPIURS.mat')

phi_1979  = PHI_data(1,2);
phi_2007  = PHI_data(29,2);
r_1979    = lognrnd(AGI_LN(1,2),sqrt(AGI_LN(1,3)),100000,1)/BLS_CPIURS(1,1);
r_2007    = lognrnd(AGI_LN(2,2),sqrt(AGI_LN(2,3)),100000,1);

%%% I.II Primitives
global gamma beta phi

gamma = 2.4;
beta  = 0.8;
eps   = beta/(gamma-beta);
kappa = 1 / (1-(1-beta)*(1+eps));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% II. Ability Calibration

%%% II.I Ability 1979
phi        = phi_1979;
k1979      = mean(r_1979)/mean(r_1979.^(1-phi_1979));
Q1979      = mean(r_1979);
x0         = [10*10e5,1000,2000]';
varphi1979 = ability_varphi(r_1979,k1979,Q1979,1,x0,10^10,10^10);
[n1979,~,~,~,~,~,~,~,uphi1979] = k_and_Q_equilibrium(varphi1979,Q1979,k1979,10^10,10^10);

%%% II. Ability 2007
phi        = phi_2007;
k2007      = mean(r_2007)/mean(r_2007.^(1-phi_2007));
Q2007      = mean(r_2007);
x0         = [10*10e5,1000,2000]';
varphi2007 = ability_varphi(r_2007,k2007,Q2007,1,x0,10^10,10^10);
[n2007,~,~,~,~,~,~,~,uphi2007] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% III. Counterfactuals

%%% III.I Holding phi constant
phi = phi_1979;
[~,~,~,~,Q2007_phi1979,~,~,~,uphi2007_phi1979] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);

%%% III.II Holding Delta constant
grid_rho   = [0.5;0.9999999];
grid_phi   = linspace(0.25,0.35,101)';
delta_grid = [zeros(1,length(grid_rho))];
delta_level_grid = [];
for n_phi = 1:1:length(grid_phi)
    phi = grid_phi(n_phi,1);
    [~,~,~,~,~,~,~,~,uphi_delta] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);
    delta_gg = [];  
    for n_rho = 1:1:length(grid_rho)
        rho_g    = grid_rho(n_rho,1);
        delta_gg = [ delta_gg   , mean(uphi_delta.^(1-rho_g))^(1/(1-rho_g)) / mean(uphi_delta) ];
    end
    delta_grid    = [delta_grid  ; delta_gg];
    n_phi
end
for n_rho = 1:1:length(grid_rho)
    rho_g      = grid_rho(n_rho,1);
    delta_1979 = (mean(uphi1979.^(1-rho_g))^(1/(1-rho_g))) / mean(uphi1979);
    delta_2007 = (mean(uphi2007.^(1-rho_g))^(1/(1-rho_g))) / mean(uphi2007);
    phi_delta  = ind2sub(delta_grid(:,n_rho),find(min(abs(delta_grid(:,n_rho)-delta_1979))==abs(delta_grid(:,n_rho)-delta_1979)));
    delta_level_grid    = [delta_level_grid;delta_1979,delta_2007,delta_2007/delta_1979]; 
    delta_grid(1,n_rho) = mean(grid_phi(phi_delta-1));
    n_rho
end

%%% III.III Statistics across rho
Welfch_C1      = [];
Qch_C1         = [];
Welfch_C2      = [];
Qch_C2         = [];

ddd_check =[];

for n_rho = 1:1:length(grid_rho)
    
    rho_g = grid_rho(n_rho,1);
    
    % Change in welfare
    Welfch_C1 = [Welfch_C1; mean( uphi2007_phi1979.^(1-rho_g))^(1/(1-rho_g)) / mean( uphi1979.^(1-rho_g))^(1/(1-rho_g)) ];

    phi = delta_grid(1,n_rho);
    [~,~,~,~,Q_delta,~,~,~,uphi_delta] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);
    Welfch_C2 = [Welfch_C2; mean( uphi_delta.^(1-rho_g))^(1/(1-rho_g)) / mean( uphi1979.^(1-rho_g))^(1/(1-rho_g)) ];
       
    % Change in Q
    Qch_C1 = [Qch_C1; Q2007_phi1979 / Q1979];
    Qch_C2 = [Qch_C2; Q_delta / Q1979];
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% IV. Plot

plot_data = [ mean(r_2007)/mean(r_1979),Qch_C1(2),Qch_C2(2);
              mean(r_2007)/mean(r_1979),Qch_C1(1),Qch_C2(1);
              (mean(uphi2007.^(1-grid_rho(2)))/mean(uphi1979.^(1-grid_rho(2)))).^(1/(1-grid_rho(2))),Welfch_C1(2),Welfch_C2(2);
              (mean(uphi2007.^(1-grid_rho(1)))/mean(uphi1979.^(1-grid_rho(1)))).^(1/(1-grid_rho(1))),Welfch_C1(1),Welfch_C2(1)];
plot_data = (plot_data.^(1/28)-1)*100;             
                       
inc_gr1  = plot_data(1,:)';
wel_gr1  = plot_data(3,:)';
inc_gr05 = plot_data(2,:)';
wel_gr05 = plot_data(4,:)';

colormap(jet(4))

figure(1)
subplot(1,2,1),
bg = bar(1:3,[inc_gr1,wel_gr1]);
set(gca,'XTickLabel',{'Data','Counterfactual \newline \phi_{1979}=\phi_{2007}','Counterfactual \newline \Delta_{1979}=\Delta_{2007}'},'fontsize',12)
yl  = ylabel('\% Annualized Growth')
leg = legend('Income growth','Welfare growth, $\rho=1$')
ylim([0,1.5])
set(gca,'YTick',[0:0.25:1.5])
set(yl,'Interpreter','Latex','fontsize',12)
set(leg,'Interpreter','Latex','fontsize',12)

subplot(1,2,2),
bg = bar(1:3,[inc_gr05,wel_gr05]);
set(gca,'XTickLabel',{'Data','Counterfactual \newline \phi_{1979}=\phi_{2007}','Counterfactual \newline \Delta_{1979}=\Delta_{2007}'},'fontsize',12)
yl  = ylabel('\% Annualized Growth')
leg = legend('Income growth','Welfare growth, $\rho=0.5$')
ylim([0,1.5])
set(gca,'YTick',[0:0.25:1.5])
set(yl,'Interpreter','Latex','fontsize',12)
set(leg,'Interpreter','Latex','fontsize',12)

set(gcf, 'Position', [0,0,800,300]);








