
clear all 
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% REPLICATES Figure 7: Trade integration and income inequality
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% I. Setup

%%% I.I Data
addpath('CODE_EQUILIBRIUM')
load('DATA/AGI_LN_approx.mat')
load('DATA/PHI.mat')
load('DATA/BLS_CPIURS.mat')

phi_2007  = PHI_data(29,2);
r_2007    = lognrnd(AGI_LN(2,2),sqrt(AGI_LN(2,3)),100000,1);

%%% I.II Primitives
global gamma beta phi
beta     = 0.80;
gamma    = 2.40;
NN       = 5;
N        = linspace(1,NN,NN)';
tau      = 2.1475;
tau_1979 = 2.2982;
F        = 675;
alpha    = 0.5550;
Fn       = F*(N.^alpha);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% II. Ability Calibration

phi        = phi_2007;
k_2007     = mean(r_2007)/mean(r_2007.^(1-phi_2007));
Q_2007     = mean(r_2007);
x0         = [10*10e5,1000,2000]';
varphi2007 = ability_varphi(r_2007,k_2007,Q_2007,1,x0,10^10,10^10);
[na,la,ya,ra,Qa,ka,ua,Phia,utota] = k_and_Q_equilibrium(varphi2007,Q_2007,k_2007,10^10,10^10);
ra_post                           = ka*(ra.^(1-phi));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% III. Gini across trade equilibria

tau_grid = linspace(1,5,801);
Gini_tau = [];
VarR_tau = [];
for t=1:1:length(tau_grid)
    [~,~,~,rtau,Qtau,ktau,~,~,~] = k_and_Q_equilibrium(varphi2007,Q_2007,k_2007,tau_grid(t),Fn);
    rtau_post = ktau*(rtau.^(1-phi));
    Gini_tau  = [Gini_tau;Gini(rtau)/Gini(ra),Gini(rtau_post)/Gini(ra_post)];
    VarR_tau  = [VarR_tau;((std(rtau/mean(rtau)))^2)/(std(ra/mean(ra)))^2,((std(rtau_post/mean(rtau_post)))^2)/((std(ra_post/mean(ra_post)))^2)];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% IV. PLOT

figure(1)
y_limits = [1,1.05];
subplot(1,2,1),
plot(tau_grid,Gini_tau(:,1),'b','LineWidth',2),hold on,
plot(tau_grid,Gini_tau(:,2),'--','Color',[0.9,0,0],'LineWidth',2),hold on,
plot([tau,tau],y_limits,'k--','LineWidth',1),hold on,
plot([tau_1979,tau_1979],y_limits,'k--','LineWidth',1),hold on,
ylim(y_limits)
text([tau-0.4,tau_1979+0.1],[1.045,1.035],cellstr(['$d_{2007}$';'$d_{1979}$']),'Interpreter','Latex','fontsize',15)
xlim([1,4])
ax = gca;
ax.XTick = [1:0.5:4];
ax.YTick = [1:0.01:1.05];
set(gca,'FontSize',12)
xl = xlabel('Variable Trade Cost $d$'),
set(xl,'Interpreter','Latex','fontsize',14)
t  = title('Gini Ratio')
set(t,'Interpreter','Latex','fontsize',16)

y_limits = [1,1.10];
subplot(1,2,2),
plot(tau_grid,VarR_tau(:,1),'b','LineWidth',2),hold on,
plot(tau_grid,VarR_tau(:,2),'--','Color',[0.9,0,0],'LineWidth',2),hold on
plot([tau,tau],y_limits,'k--','LineWidth',1),hold on,
plot([tau_1979,tau_1979],y_limits,'k--','LineWidth',1),hold on,
ylim(y_limits)
text([tau-0.4,tau_1979+0.1],[1.04,1.02],cellstr(['$d_{2007}$';'$d_{1979}$']),'Interpreter','Latex','fontsize',15)
xlim([1,4])
ax = gca;
ax.XTick = [1:0.5:4];
ax.YTick = [1:0.02:1.10];
set(gca,'FontSize',12)
xl = xlabel('Variable Trade Cost $d$'),
set(xl,'Interpreter','Latex','fontsize',14)
leg= legend('$r_{\varphi}$, Pre-Tax','$kr_{\varphi}^{1-\phi}$, Post-Tax');
set(leg,'Interpreter','Latex','fontsize',14)
t  = title('Variance($r$/Mean($r$)) Ratio')
set(t,'Interpreter','Latex','fontsize',16)

set(gcf, 'Position', [0,0,800,300]);


