
clear all 
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% REPLICATES TABLE 1: WELFARE, INEQUALITY, AND COSTLY REDISTRIBUTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% I. Setup

%%% I.I Data
addpath('CODE_EQUILIBRIUM')
load('DATA/AGI_LN_approx.mat')
load('DATA/PHI.mat')
load('DATA/BLS_CPIURS.mat')

phi_1979  = PHI_data(1,2);
phi_2007  = PHI_data(29,2);
r_1979    = lognrnd(AGI_LN(1,2),sqrt(AGI_LN(1,3)),100000,1)/BLS_CPIURS(1,1);
r_2007    = lognrnd(AGI_LN(2,2),sqrt(AGI_LN(2,3)),100000,1);

%%% I.II Primitives
global gamma beta phi

gamma = 2.4;
beta  = 0.8;
eps   = beta/(gamma-beta);
kappa = 1 / (1-(1-beta)*(1+eps));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% II. Ability Calibration

%%% II.I Ability 1979
phi        = phi_1979;
k1979      = mean(r_1979)/mean(r_1979.^(1-phi_1979));
Q1979      = mean(r_1979);
x0         = [10*10e5,1000,2000]';
varphi1979 = ability_varphi(r_1979,k1979,Q1979,1,x0,10^10,10^10);
[n1979,~,~,~,~,~,~,~,uphi1979] = k_and_Q_equilibrium(varphi1979,Q1979,k1979,10^10,10^10);

%%% II. Ability 2007
phi        = phi_2007;
k2007      = mean(r_2007)/mean(r_2007.^(1-phi_2007));
Q2007      = mean(r_2007);
x0         = [10*10e5,1000,2000]';
varphi2007 = ability_varphi(r_2007,k2007,Q2007,1,x0,10^10,10^10);
[n2007,~,~,~,~,~,~,~,uphi2007] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 3) Welfare, Inequality and Costly Redistribution

%%% Statistics across rho
grid_rho    = [0,0.25,0.5,0.9999999,1.5,2]';
Welfch      = [];
Qch         = [];
Qtildech    = [];
for nrho = 1:1:length(grid_rho)
    
    rho_g = grid_rho(nrho,1);
    
    % Change in welfare
    Welfch = [Welfch; mean( uphi2007.^(1-rho_g))^(1/(1-rho_g)) / mean( uphi1979.^(1-rho_g))^(1/(1-rho_g)) ];
    
    % Change in Q
    Qch    = [Qch; Q2007 / Q1979];
    
    % Change in Q'
    phi = 0;
    [~,~,~,r1979_tilde,Q1979_tilde,k1979_tilde,~,~,uphi1979_tilde] = k_and_Q_equilibrium(varphi1979,Q1979,k1979,10^10,10^10);
    [~,~,~,r2007_tilde,Q2007_tilde,k2007_tilde,~,~,uphi2007_tilde] = k_and_Q_equilibrium(varphi2007,Q2007,k2007,10^10,10^10);
    Qtildech = [Qtildech; Q2007_tilde/Q1979_tilde];
    
end

%%% Results
const1 = (1+eps*phi_2007)/(1+eps*phi_1979); 
fprintf('\n'),display('-> Results for table 1 are:')
TABLE1 = [Welfch./(const1.*Qch),const1*ones(length(grid_rho),1),Qch./Qtildech,Qtildech,Welfch];
TABLE1 = round((TABLE1.^(1/28)-1)*100,2)











