
clear all 
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% REPLICATES TABLE 2: WELFARE GAINS FROM TRADE AND INDUCED INEQUALITY
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% I. Setup

%%% I.I Data
addpath('CODE_EQUILIBRIUM')
load('DATA/AGI_LN_approx.mat')
load('DATA/PHI.mat')
load('DATA/BLS_CPIURS.mat')

phi_1979  = PHI_data(1,2);
phi_2007  = PHI_data(29,2);
r_2007    = lognrnd(AGI_LN(2,2),sqrt(AGI_LN(2,3)),100000,1);
k_2007    = mean(r_2007)/mean(r_2007.^(1-phi_2007));
Q_2007    = mean(r_2007);

%%% I.II Primitives
global gamma beta phi
beta        = 0.80;
% [gamma , tau_2007 , F_2007 , alpha_2007 , tau_1979] 
parameters  = [4   2.1465 675 0.5535 2.2996
               2.4 2.147  675 0.5545 2.2982
               1.6 2.148  675 0.5535 2.295];               
NN    = 5;
N     = linspace(1,NN,NN)';
x0    = [10*10e5,1000,2000;
         10*10e3,500,500;
         10*10e3,500,500]';
     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% II. Counterfactuals

TABLE2 = zeros(3,6);

for par=1:1:3
     
    gamma       = parameters(par,1);
    taug_2007   = parameters(par,2);
    Fg_2007     = parameters(par,3);
    alphag_2007 = parameters(par,4);
    taug_1979   = parameters(par,5);
    Fng         = Fg_2007*(N.^alphag_2007);
    
    phi       = phi_2007;
    [varphig] = ability_varphi(r_2007,k_2007,Q_2007,N,x0(:,par),taug_2007,Fng);
    
    [~,lg,~,rg,Qg,kg,~,~,utotg]           = k_and_Q_equilibrium(varphig,Q_2007,k_2007,taug_2007,Fng);
    [~,lga1,~,rga1,Qga1,kga1,~,~,utotga1] = k_and_Q_equilibrium(varphig,Q_2007,k_2007,taug_1979,Fng);
    [~,lga2,~,rga2,Qga2,kga2,~,~,utotga2] = k_and_Q_equilibrium(varphig,Q_2007,k_2007,10000,Fng);
    
    % Change in real consumption
    cg   = utotg   + (1/gamma)*(lg.^gamma);
    cga1 = utotga1 + (1/gamma)*(lga1.^gamma);
    cga2 = utotga2 + (1/gamma)*(lga2.^gamma);
    
    TABLE2(par,1:2) = [mean(cg)/mean(cga1),mean(cg)/mean(cga2)];
    
    % Gains from Trade
    TABLE2(par,3:4) = [mean(utotg)/mean(utotga1),mean(utotg)/mean(utotga2)];
    
    % Gini Counterfactual
    TABLE2(par,5:6) = [Gini(kg*rg.^(1-phi))/Gini(kga1*rga1.^(1-phi)),Gini(kg*rg.^(1-phi))/Gini(kga2*rga2.^(1-phi))];

end

%%% TABLE2 
TABLE2 = round((TABLE2-1)*100,1)
